//***********************************
// METHOD VARIABLES
//***********************************

VARIABLE CURRENT_LIMIT_MAX
{
	LABEL "Current Limit Maximum";
	HELP "Variable parameter value dependant on other drive parameter values.";
			
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE INTEGER (4)
	{
		SCALING_FACTOR 0.1; 
	}
}

VARIABLE NEG_CURRENT_LIMIT_MAX
{
	LABEL "Current Limit Minimum";
	HELP "Variable parameter value dependant on other drive parameter values.";
			
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE INTEGER (4)
	{
		SCALING_FACTOR 0.1; 
	}
}

VARIABLE MOTORIZED_POT_STATUS
{
	LABEL "Motorized Pot Status";
	HELP "Parameter indicates whether the Motorized Pot is Enabled or Disabled";
			
	HANDLING READ;
	CLASS LOCAL;
	TYPE ENUMERATED (1)
	{
		{0, "Disabled"},
		{1, "Enabled"}
	}
}

// Even though the below works in the UI, it doesn't have any useful function since
// any changes the user makes are lost when AMS is closed (since local vars are not 
// saved to any file).  Therefore, when user comes back into AMS all checkboxes
// will be unchecked again.

VARIABLE SUPPRESSION_BITMAP
{
	LABEL "Suppression Bitmap";
	HELP "Bitmap parameter used to suppress various Advisory Alerts.";

	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE BIT_ENUMERATED (1)
	{
		{0x01, "Suppress Current Limit Alert", "Suppress Current Limit Alert"},
		{0x02, "Suppress Braking Resistor Alarm Alert", "Suppress Braking Resistor Alarm Alert"},
		{0x04, "Suppress Mains Loss Detected Alert", "Suppress Mains Loss Detected Alert"},
		{0x08, "Suppress Overload Alert", "Suppress Overload Alert"},
		{0x10, "Suppress Drive Temperature Alarm Alert", "Suppress Drive Temperature Alarm Alert"}
	}
	DEFAULT_VALUE 0;
}

VARIABLE SUPPRESS_CURRENT_LIMIT
{
	LABEL "Suppress Current Limit Alert";
	HELP "Used to suppress the Drive Output at Current Limit Alert indicator."

	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE  ENUMERATED (1)
	{
		{0, ENUMID164_VAL0_MNEMONIC},
		{1, ENUMID164_VAL1_MNEMONIC}
	}
	DEFAULT_VALUE 0;
}

VARIABLE SUPPRESS_OVERLOAD
{
	LABEL "Suppress Overload Alert";
	HELP "Used to suppress the Overload Alert indicator."

	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE  ENUMERATED (1)
	{
		{0, ENUMID164_VAL0_MNEMONIC},
		{1, ENUMID164_VAL1_MNEMONIC}
	}
	DEFAULT_VALUE 0;
}

VARIABLE SUPPRESS_BRAKE_RES
{
	LABEL "Suppress Braking Resistor Alarm Alert";
	HELP "Used to suppress the Braking Resistor Alarm Alert indicator."

	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE  ENUMERATED (1)
	{
		{0, ENUMID164_VAL0_MNEMONIC},
		{1, ENUMID164_VAL1_MNEMONIC}
	}
	DEFAULT_VALUE 0;
}

VARIABLE SUPPRESS_MAINS_LOSS
{
	LABEL "Suppress Mains Loss Detected Alert";
	HELP "Used to suppress the Mains Loss Detected Alert indicator."

	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE  ENUMERATED (1)
	{
		{0, ENUMID164_VAL0_MNEMONIC},
		{1, ENUMID164_VAL1_MNEMONIC}
	}
	DEFAULT_VALUE 0;
}

VARIABLE SUPPRESS_OVERTEMP
{
	LABEL "Suppress Drive Temperature Alarm Alert";
	HELP "Used to suppress the Drive Temperature Alarm Alert indicator."

	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE  ENUMERATED (1)
	{
		{0, ENUMID164_VAL0_MNEMONIC},
		{1, ENUMID164_VAL1_MNEMONIC}
	}
	DEFAULT_VALUE 0;
}

VARIABLE POWER_SUPPLY_SELECTION
{
	LABEL "Power Supply Type";
	HELP "Parameter used to select the supply source that the drive will be connected to.  Is used to "
		 "select the default parameter set that will be applied to the drive.";
	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE ENUMERATED (1)
	{
		{0, "60Hz power source (North America/USA)"},
		{1, "50Hz power source (Europe)"}
	}
	DEFAULT_VALUE 1;
}

VARIABLE SPEED_INPUT_SELECTION
{
	LABEL "Speed Input";
	HELP "This parameter is used to select the speed reference for the drive.";
	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE ENUMERATED (1)
	{
		{0, "Local/Remote Analog"},
		{1, "Local Analog or 3 Preset References"},
		{2, "Preset References"},
		{3, "Keypad"},
		{4, "Motorized Potentiometer"},
		{5, "Torque Mode"},
		{6, "PID Control"},
		{7, "Affinity Control"}
	}
	DEFAULT_VALUE 3;
}

VARIABLE GUIDED_SETUP_COMPLETION_SELECTION
{
	LABEL "Wizard Completion Action";
	HELP "Choose how to end the Guided Setup Wizard.";
	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE ENUMERATED (1)
	{
		{0, "Reset and Save Settings in Drive"},
		{1, "Reset but do not Save Settings in Drive"}
	}
	DEFAULT_VALUE 0;
}

VARIABLE AUTO_TUNE_SELECTION
{
	LABEL "Auto-Tune";
	HELP "Choose which auto-tune test to perform.";
	VALIDITY TRUE;
	HANDLING READ&WRITE;
	CLASS LOCAL;
	TYPE ENUMERATED (1)
	{
		{1, "Stationary Test"},
		{2, "Rotating Test"}
	}
	DEFAULT_VALUE 1;
}

VARIABLE DD_REV
{
	LABEL "DD Revision";
	HELP "The current revision of the Device Description files being used by AMS Device Manager.";
	VALIDITY TRUE;
	HANDLING READ;
	CLASS LOCAL;
	TYPE FLOAT;
	DEFAULT_VALUE 1.0;
}

// The below variable is kind of a kludge since there is no parameter to read within the device
// that holds the Device Type.  Therefore, I read a parameter from the device, and regardless of
// the value that is returned, I use "Commander SK" as the result.

VARIABLE DRIVE_TYPE
{
	LABEL "Device Type";
	HELP "Displays the device type or drive model.";
	VALIDITY TRUE;
	HANDLING READ;
	CLASS DEVICE;
	TYPE ENUMERATED (1)
	{
		{0, "Commander SK"},
		{1, "Commander SK"},
		{2, "Commander SK"},
		{3, "Commander SK"}
	}
	CONSTANT_UNIT UNITID350;

	PRE_READ_ACTIONS
	{
		DEFINITION
		{
			write_map_info(1, 0x2B74);
		}
	}
}

// Below is the read command for the variable DRIVE_TYPE.  This is not in the file
// drv_rdwrtcmds.h  or slot_rdwrtcmds.h because it is not a drive parameter (local only)
read_param_1 (read_DRIVE_TYPE, DRIVE_TYPE) 